local params = ...

local zwave = require "zwave"
local core = require "core"
local storage = require "storage"

local zwave_node = zwave.get_node( params.node_id )

for _, channel in ipairs( zwave_node.channels ) do
    for _, cc in ipairs( channel.classes ) do
        if cc.id == 0x25 then -- Binary Switch command class ID
            -- add device
            local device = {
                name = "MySwitch",
                gateway_id = core.get_gateway()._id,
                category = "switch",
                subcategory = "interior_plugin",
                type = "switch.outlet",
                device_type_id = math.floor( zwave_node.manufacturerId ) .. '_' .. 
                                 math.floor( zwave_node.productType ) .. '_' .. 
                                 math.floor( zwave_node.productId ),
                battery_powered = false
            }
            local device_id = core.add_device( device )
            storage.set_string( zwave_node._id, device_id )
            storage.set_string( device_id, zwave_node._id )
            
            -- add item
            local item = {
                device_id = device_id,
                name = "switch",
                value_type = "bool",
                value = false,
                has_getter = true,
                has_setter = true
            }
             
            local item_id = core.add_item( item )
            local item_descriptor = {
                item_name = "switch",
                node_id = zwave_node._id,
                class_id = cc.id,
                channel_id = channel.id
            }
            storage.set_string(
                loadfile( "HUB:my_first_plugin/scripts/utils/item_descriptor_utils" )().to_string( item_descriptor ), 
                item_id
            )
            storage.set_table( item_id, item_descriptor )
            
            return
        end
    end
end
